Padding

Struct Padding 

pub struct Padding {
    pub content: Text,
    pub top: usize,
    pub right: usize,
    pub bottom: usize,
    pub left: usize,
    pub style: Style,
    pub expand: bool,
}
A renderable that adds whitespace padding around Text content.

Fields

content: Text

The inner content to pad.

top: usize

Top padding (blank lines above content).

right: usize

Right padding (spaces after each content line).

bottom: usize

Bottom padding (blank lines below content).

left: usize

Left padding (spaces before each content line).

style: Style

Style applied to the padding whitespace.

expand: bool

If true, expand to fill the available width.

Implementations

Source

impl Padding

pub fn wrap(content: Text, pad: impl Into<PaddingDimensions>) -> Self

Wrap content in padding with default style and expand: true. pad accepts usize (uniform), (v, h), or (t, r, b, l). For styled padding background or expand: false, use new.

let p = Padding::wrap(Text::new("Hello", Style::null()), (2, 4));
pub fn new( content: Text, pad: PaddingDimensions, style: Style, expand: bool, ) -> Self

Create a new Padding around the given content.

pub fn indent(content: Text, level: usize) -> Self

Convenience: create padding that acts as a left-indent.

pub fn measure( &self, _console: &Console, options: &ConsoleOptions, ) -> Measurement

Measure the minimum and maximum width requirements.