Module scope

Module scope 

Scope module – renders a mapping of key-value pairs in a panel.

In Python, render_scope introspects a dict and displays variable names and their repr values inside a bordered panel. In Rust we accept pre-formatted &str pairs instead.

Structs

Scope
A renderable that displays key-value pairs inside a bordered panel.

Functions

render_scope
Render key-value pairs as a panel with a table grid inside.