pub struct ConsoleBuilder { /* private fields */ }Expand description
Builder for constructing a Console with custom options.
Implementations
Sourceimpl ConsoleBuilder
impl ConsoleBuilder
Sourcepub fn color_system(self, cs: &str) -> Self
pub fn color_system(self, cs: &str) -> Self
Set the color system by name ("standard", "256", "truecolor", "windows").
Sourcepub fn force_terminal(self, f: bool) -> Self
pub fn force_terminal(self, f: bool) -> Self
Force or prevent terminal detection regardless of the actual environment.
Sourcepub fn color_system_override(self, cs: ColorSystem) -> Self
pub fn color_system_override(self, cs: ColorSystem) -> Self
Explicitly override the color system, taking priority over both
environment variables and the string-based color_system method.
Sourcepub fn soft_wrap(self, sw: bool) -> Self
pub fn soft_wrap(self, sw: bool) -> Self
Enable or disable soft wrapping (allows lines to exceed terminal width).