pub struct Padding {
pub content: Text,
pub top: usize,
pub right: usize,
pub bottom: usize,
pub left: usize,
pub style: Style,
pub expand: bool,
}Expand description
A renderable that adds whitespace padding around Text content.
Fields
content: TextThe inner content to pad.
top: usizeTop padding (blank lines above content).
right: usizeRight padding (spaces after each content line).
bottom: usizeBottom padding (blank lines below content).
left: usizeLeft padding (spaces before each content line).
style: StyleStyle applied to the padding whitespace.
expand: boolIf true, expand to fill the available width.
Implementations
Sourceimpl Padding
impl Padding
Sourcepub fn wrap(content: Text, pad: impl Into<PaddingDimensions>) -> Self
pub fn wrap(content: Text, pad: impl Into<PaddingDimensions>) -> Self
Wrap content in padding with default style and expand: true.
pad accepts usize (uniform), (v, h), or (t, r, b, l). For
styled padding background or expand: false, use new.
let p = Padding::wrap(Text::new("Hello", Style::null()), (2, 4));Sourcepub fn new(
content: Text,
pad: PaddingDimensions,
style: Style,
expand: bool,
) -> Self
pub fn new( content: Text, pad: PaddingDimensions, style: Style, expand: bool, ) -> Self
Create a new Padding around the given content.
Sourcepub fn indent(content: Text, level: usize) -> Self
pub fn indent(content: Text, level: usize) -> Self
Convenience: create padding that acts as a left-indent.
Sourcepub fn measure(
&self,
_console: &Console,
options: &ConsoleOptions,
) -> Measurement
pub fn measure( &self, _console: &Console, options: &ConsoleOptions, ) -> Measurement
Measure the minimum and maximum width requirements.